# Grun human pancreas (CEL-seq2) 

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This workflow performs an analysis of the @grun2016denovo CEL-seq2 dataset consisting of human pancreas cells from various donors.

## Data loading


```r
library(scRNAseq)
sce.grun <- GrunPancreasData()
```

We convert to Ensembl identifiers, and we remove duplicated genes or genes without Ensembl IDs.


```r
library(org.Hs.eg.db)
gene.ids <- mapIds(org.Hs.eg.db, keys=rowData(sce.grun)$symbol,
    keytype="SYMBOL", column="ENSEMBL")

keep <- !is.na(gene.ids) & !duplicated(gene.ids)
sce.grun <- sce.grun[keep,]
rownames(sce.grun) <- gene.ids[keep]
```

## Quality control


```r
unfiltered <- sce.grun
```

This dataset lacks mitochondrial genes so we will do without them for quality control.
We compute the median and MAD while blocking on the donor;
for donors where the assumption of a majority of high-quality cells seems to be violated (Figure \@ref(fig:unref-grun-qc-dist)),
we compute an appropriate threshold using the other donors as specified in the `subset=` argument.


```r
library(scater)
stats <- perCellQCMetrics(sce.grun)

qc <- quickPerCellQC(stats, percent_subsets="altexps_ERCC_percent",
    batch=sce.grun$donor,
    subset=sce.grun$donor %in% c("D17", "D7", "D2"))

sce.grun <- sce.grun[,!qc$discard]
```


```r
colData(unfiltered) <- cbind(colData(unfiltered), stats)
unfiltered$discard <- qc$discard

gridExtra::grid.arrange(
    plotColData(unfiltered, x="donor", y="sum", colour_by="discard") +
        scale_y_log10() + ggtitle("Total count"),
    plotColData(unfiltered, x="donor", y="detected", colour_by="discard") +
        scale_y_log10() + ggtitle("Detected features"),
    plotColData(unfiltered, x="donor", y="altexps_ERCC_percent",
        colour_by="discard") + ggtitle("ERCC percent"),
    ncol=2
)
```

<div class="figure">
<img src="grun-pancreas_files/figure-html/unref-grun-qc-dist-1.png" alt="Distribution of each QC metric across cells from each donor of the Grun pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded." width="672" />
<p class="caption">(\#fig:unref-grun-qc-dist)Distribution of each QC metric across cells from each donor of the Grun pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>


```r
colSums(as.matrix(qc), na.rm=TRUE)
```

```
##              low_lib_size            low_n_features high_altexps_ERCC_percent 
##                       451                       510                       606 
##                   discard 
##                       664
```

## Normalization 


```r
library(scran)
set.seed(1000) # for irlba. 
clusters <- quickCluster(sce.grun)
sce.grun <- computeSumFactors(sce.grun, clusters=clusters)
sce.grun <- logNormCounts(sce.grun)
```


```r
summary(sizeFactors(sce.grun))
```

```
##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
##   0.098   0.508   0.791   1.000   1.230  10.072
```


```r
plot(librarySizeFactors(sce.grun), sizeFactors(sce.grun), pch=16,
    xlab="Library size factors", ylab="Deconvolution factors", log="xy")
```

<div class="figure">
<img src="grun-pancreas_files/figure-html/unref-grun-norm-1.png" alt="Relationship between the library size factors and the deconvolution size factors in the Grun pancreas dataset." width="672" />
<p class="caption">(\#fig:unref-grun-norm)Relationship between the library size factors and the deconvolution size factors in the Grun pancreas dataset.</p>
</div>

## Variance modelling

We block on a combined plate and donor factor.


```r
block <- paste0(sce.grun$sample, "_", sce.grun$donor)
dec.grun <- modelGeneVarWithSpikes(sce.grun, spikes="ERCC", block=block)
top.grun <- getTopHVGs(dec.grun, prop=0.1)
```

We examine the number of cells in each level of the blocking factor.


```r
table(block)
```

```
## block
##                  CD13+ sorted cells_D17       CD24+ CD44+ live sorted cells_D17 
##                                      87                                      87 
##                  CD63+ sorted cells_D10                TGFBR3+ sorted cells_D17 
##                                      40                                      90 
## exocrine fraction, live sorted cells_D2 exocrine fraction, live sorted cells_D3 
##                                      82                                       7 
##        live sorted cells, library 1_D10        live sorted cells, library 1_D17 
##                                      33                                      88 
##         live sorted cells, library 1_D3         live sorted cells, library 1_D7 
##                                      25                                      85 
##        live sorted cells, library 2_D10        live sorted cells, library 2_D17 
##                                      35                                      83 
##         live sorted cells, library 2_D3         live sorted cells, library 2_D7 
##                                      27                                      84 
##         live sorted cells, library 3_D3         live sorted cells, library 3_D7 
##                                      16                                      83 
##         live sorted cells, library 4_D3         live sorted cells, library 4_D7 
##                                      29                                      83
```


```r
par(mfrow=c(6,3))
blocked.stats <- dec.grun$per.block
for (i in colnames(blocked.stats)) {
    current <- blocked.stats[[i]]
    plot(current$mean, current$total, main=i, pch=16, cex=0.5,
        xlab="Mean of log-expression", ylab="Variance of log-expression")
    curfit <- metadata(current)
    points(curfit$mean, curfit$var, col="red", pch=16)
    curve(curfit$trend(x), col='dodgerblue', add=TRUE, lwd=2)
}
```

<div class="figure">
<img src="grun-pancreas_files/figure-html/unref-416b-variance-1.png" alt="Per-gene variance as a function of the mean for the log-expression values in the Grun pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor." width="672" />
<p class="caption">(\#fig:unref-416b-variance)Per-gene variance as a function of the mean for the log-expression values in the Grun pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor.</p>
</div>

## Data integration


```r
library(batchelor)
set.seed(1001010)
merged.grun <- fastMNN(sce.grun, subset.row=top.grun, batch=sce.grun$donor)
```


```r
metadata(merged.grun)$merge.info$lost.var
```

```
##           D10     D17       D2      D3      D7
## [1,] 0.030046 0.03098 0.000000 0.00000 0.00000
## [2,] 0.007559 0.01196 0.038754 0.00000 0.00000
## [3,] 0.004060 0.00524 0.008091 0.05278 0.00000
## [4,] 0.013901 0.01682 0.017032 0.01576 0.05501
```

## Dimensionality reduction


```r
set.seed(100111)
merged.grun <- runTSNE(merged.grun, dimred="corrected")
```

## Clustering


```r
snn.gr <- buildSNNGraph(merged.grun, use.dimred="corrected")
colLabels(merged.grun) <- factor(igraph::cluster_walktrap(snn.gr)$membership)
```


```r
table(Cluster=colLabels(merged.grun), Donor=merged.grun$batch)
```

```
##        Donor
## Cluster D10 D17  D2  D3  D7
##       1  17  74   3   2  77
##       2   6  11   5   7   9
##       3  27 107  43  13 115
##       4  12 128   0   0  62
##       5  32  71  31  80  28
##       6   5  14   0   0  10
##       7   4  13   0   0   1
##       8   5  17   0   2  33
```


```r
gridExtra::grid.arrange(
    plotTSNE(merged.grun, colour_by="label"),
    plotTSNE(merged.grun, colour_by="batch"),
    ncol=2
)
```

<div class="figure">
<img src="grun-pancreas_files/figure-html/unref-grun-tsne-1.png" alt="Obligatory $t$-SNE plots of the Grun pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right)." width="672" />
<p class="caption">(\#fig:unref-grun-tsne)Obligatory $t$-SNE plots of the Grun pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right).</p>
</div>

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.4.0 RC (2024-04-16 r86468)
Platform: x86_64-pc-linux-gnu
Running under: Ubuntu 22.04.4 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.20-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.10.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] batchelor_1.19.1            scran_1.31.3               
 [3] scater_1.31.2               ggplot2_3.5.1              
 [5] scuttle_1.13.1              org.Hs.eg.db_3.19.1        
 [7] AnnotationDbi_1.65.2        scRNAseq_2.17.10           
 [9] SingleCellExperiment_1.25.1 SummarizedExperiment_1.33.3
[11] Biobase_2.63.1              GenomicRanges_1.55.4       
[13] GenomeInfoDb_1.39.14        IRanges_2.37.1             
[15] S4Vectors_0.41.7            BiocGenerics_0.49.1        
[17] MatrixGenerics_1.15.1       matrixStats_1.3.0          
[19] BiocStyle_2.31.0            rebook_1.13.0              

loaded via a namespace (and not attached):
  [1] jsonlite_1.8.8            CodeDepends_0.6.6        
  [3] magrittr_2.0.3            ggbeeswarm_0.7.2         
  [5] GenomicFeatures_1.55.4    gypsum_0.99.19           
  [7] farver_2.1.1              rmarkdown_2.26           
  [9] BiocIO_1.13.1             zlibbioc_1.49.3          
 [11] vctrs_0.6.5               memoise_2.0.1            
 [13] Rsamtools_2.19.4          DelayedMatrixStats_1.25.4
 [15] RCurl_1.98-1.14           htmltools_0.5.8.1        
 [17] S4Arrays_1.3.7            AnnotationHub_3.11.5     
 [19] curl_5.2.1                BiocNeighbors_1.21.2     
 [21] Rhdf5lib_1.25.3           SparseArray_1.3.7        
 [23] rhdf5_2.47.7              sass_0.4.9               
 [25] alabaster.base_1.3.23     bslib_0.7.0              
 [27] alabaster.sce_1.3.3       httr2_1.0.1              
 [29] cachem_1.0.8              ResidualMatrix_1.13.0    
 [31] GenomicAlignments_1.39.5  igraph_2.0.3             
 [33] lifecycle_1.0.4           pkgconfig_2.0.3          
 [35] rsvd_1.0.5                Matrix_1.7-0             
 [37] R6_2.5.1                  fastmap_1.1.1            
 [39] GenomeInfoDbData_1.2.12   digest_0.6.35            
 [41] colorspace_2.1-0          paws.storage_0.5.0       
 [43] dqrng_0.3.2               irlba_2.3.5.1            
 [45] ExperimentHub_2.11.3      RSQLite_2.3.6            
 [47] beachmat_2.19.4           labeling_0.4.3           
 [49] filelock_1.0.3            fansi_1.0.6              
 [51] httr_1.4.7                abind_1.4-5              
 [53] compiler_4.4.0            bit64_4.0.5              
 [55] withr_3.0.0               BiocParallel_1.37.1      
 [57] viridis_0.6.5             DBI_1.2.2                
 [59] highr_0.10                HDF5Array_1.31.6         
 [61] alabaster.ranges_1.3.3    alabaster.schemas_1.3.1  
 [63] rappdirs_0.3.3            DelayedArray_0.29.9      
 [65] bluster_1.13.0            rjson_0.2.21             
 [67] tools_4.4.0               vipor_0.4.7              
 [69] beeswarm_0.4.0            glue_1.7.0               
 [71] restfulr_0.0.15           rhdf5filters_1.15.5      
 [73] grid_4.4.0                Rtsne_0.17               
 [75] cluster_2.1.6             generics_0.1.3           
 [77] gtable_0.3.5              ensembldb_2.27.1         
 [79] metapod_1.11.1            ScaledMatrix_1.11.1      
 [81] BiocSingular_1.19.0       utf8_1.2.4               
 [83] XVector_0.43.1            ggrepel_0.9.5            
 [85] BiocVersion_3.19.1        pillar_1.9.0             
 [87] limma_3.59.10             dplyr_1.1.4              
 [89] BiocFileCache_2.11.2      lattice_0.22-6           
 [91] rtracklayer_1.63.3        bit_4.0.5                
 [93] tidyselect_1.2.1          paws.common_0.7.2        
 [95] locfit_1.5-9.9            Biostrings_2.71.6        
 [97] knitr_1.46                gridExtra_2.3            
 [99] bookdown_0.39             ProtGenerics_1.35.4      
[101] edgeR_4.1.33              xfun_0.43                
[103] statmod_1.5.0             UCSC.utils_0.99.7        
[105] lazyeval_0.2.2            yaml_2.3.8               
[107] evaluate_0.23             codetools_0.2-20         
[109] tibble_3.2.1              alabaster.matrix_1.3.13  
[111] BiocManager_1.30.22       graph_1.81.1             
[113] cli_3.6.2                 munsell_0.5.1            
[115] jquerylib_0.1.4           Rcpp_1.0.12              
[117] dir.expiry_1.11.0         dbplyr_2.5.0             
[119] png_0.1-8                 XML_3.99-0.16.1          
[121] parallel_4.4.0            blob_1.2.4               
[123] AnnotationFilter_1.27.0   sparseMatrixStats_1.15.1 
[125] bitops_1.0-7              viridisLite_0.4.2        
[127] alabaster.se_1.3.4        scales_1.3.0             
[129] crayon_1.5.2              rlang_1.1.3              
[131] cowplot_1.1.3             KEGGREST_1.43.1          
```
</div>
