# Muraro human pancreas (CEL-seq)

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This performs an analysis of the @muraro2016singlecell CEL-seq dataset,
consisting of human pancreas cells from various donors.

## Data loading


```r
library(scRNAseq)
sce.muraro <- MuraroPancreasData()
```

Converting back to Ensembl identifiers.


```r
library(AnnotationHub)
edb <- AnnotationHub()[["AH73881"]]
gene.symb <- sub("__chr.*$", "", rownames(sce.muraro))
gene.ids <- mapIds(edb, keys=gene.symb, 
    keytype="SYMBOL", column="GENEID")

# Removing duplicated genes or genes without Ensembl IDs.
keep <- !is.na(gene.ids) & !duplicated(gene.ids)
sce.muraro <- sce.muraro[keep,]
rownames(sce.muraro) <- gene.ids[keep]
```

## Quality control


```r
unfiltered <- sce.muraro
```

This dataset lacks mitochondrial genes so we will do without.
For the one batch that seems to have a high proportion of low-quality cells, we compute an appropriate filter threshold using a shared median and MAD from the other batches (Figure \@ref(fig:unref-muraro-qc-dist)).


```r
library(scater)
stats <- perCellQCMetrics(sce.muraro)
qc <- quickPerCellQC(stats, percent_subsets="altexps_ERCC_percent",
    batch=sce.muraro$donor, subset=sce.muraro$donor!="D28")
sce.muraro <- sce.muraro[,!qc$discard]
```


```r
colData(unfiltered) <- cbind(colData(unfiltered), stats)
unfiltered$discard <- qc$discard

gridExtra::grid.arrange(
    plotColData(unfiltered, x="donor", y="sum", colour_by="discard") +
        scale_y_log10() + ggtitle("Total count"),
    plotColData(unfiltered, x="donor", y="detected", colour_by="discard") +
        scale_y_log10() + ggtitle("Detected features"),
    plotColData(unfiltered, x="donor", y="altexps_ERCC_percent",
        colour_by="discard") + ggtitle("ERCC percent"),
    ncol=2
)
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-qc-dist-1.png" alt="Distribution of each QC metric across cells from each donor in the Muraro pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded." width="672" />
<p class="caption">(\#fig:unref-muraro-qc-dist)Distribution of each QC metric across cells from each donor in the Muraro pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>

We have a look at the causes of removal:


```r
colSums(as.matrix(qc))
```

```
##              low_lib_size            low_n_features high_altexps_ERCC_percent 
##                       663                       700                       738 
##                   discard 
##                       773
```

## Normalization


```r
library(scran)
set.seed(1000)
clusters <- quickCluster(sce.muraro)
sce.muraro <- computeSumFactors(sce.muraro, clusters=clusters)
sce.muraro <- logNormCounts(sce.muraro)
```


```r
summary(sizeFactors(sce.muraro))
```

```
##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
##   0.088   0.541   0.821   1.000   1.211  13.987
```


```r
plot(librarySizeFactors(sce.muraro), sizeFactors(sce.muraro), pch=16,
    xlab="Library size factors", ylab="Deconvolution factors", log="xy")
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-norm-1.png" alt="Relationship between the library size factors and the deconvolution size factors in the Muraro pancreas dataset." width="672" />
<p class="caption">(\#fig:unref-muraro-norm)Relationship between the library size factors and the deconvolution size factors in the Muraro pancreas dataset.</p>
</div>

## Variance modelling

We block on a combined plate and donor factor.


```r
block <- paste0(sce.muraro$plate, "_", sce.muraro$donor)
dec.muraro <- modelGeneVarWithSpikes(sce.muraro, "ERCC", block=block)
top.muraro <- getTopHVGs(dec.muraro, prop=0.1)
```


```r
par(mfrow=c(8,4))
blocked.stats <- dec.muraro$per.block
for (i in colnames(blocked.stats)) {
    current <- blocked.stats[[i]]
    plot(current$mean, current$total, main=i, pch=16, cex=0.5,
        xlab="Mean of log-expression", ylab="Variance of log-expression")
    curfit <- metadata(current)
    points(curfit$mean, curfit$var, col="red", pch=16)
    curve(curfit$trend(x), col='dodgerblue', add=TRUE, lwd=2)
}
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-variance-1.png" alt="Per-gene variance as a function of the mean for the log-expression values in the Muraro pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor." width="672" />
<p class="caption">(\#fig:unref-muraro-variance)Per-gene variance as a function of the mean for the log-expression values in the Muraro pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor.</p>
</div>

## Data integration


```r
library(batchelor)
set.seed(1001010)
merged.muraro <- fastMNN(sce.muraro, subset.row=top.muraro, 
    batch=sce.muraro$donor)
```

We use the proportion of variance lost as a diagnostic measure:


```r
metadata(merged.muraro)$merge.info$lost.var
```

```
##           D28      D29      D30     D31
## [1,] 0.060847 0.024121 0.000000 0.00000
## [2,] 0.002646 0.003018 0.062421 0.00000
## [3,] 0.003449 0.002641 0.002598 0.08162
```

## Dimensionality reduction


```r
set.seed(100111)
merged.muraro <- runTSNE(merged.muraro, dimred="corrected")
```

## Clustering


```r
snn.gr <- buildSNNGraph(merged.muraro, use.dimred="corrected")
colLabels(merged.muraro) <- factor(igraph::cluster_walktrap(snn.gr)$membership)
```


```r
tab <- table(Cluster=colLabels(merged.muraro), CellType=sce.muraro$label)
library(pheatmap)
pheatmap(log10(tab+10), color=viridis::viridis(100))
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-seger-heat-1.png" alt="Heatmap of the frequency of cells from each cell type label in each cluster." width="672" />
<p class="caption">(\#fig:unref-seger-heat)Heatmap of the frequency of cells from each cell type label in each cluster.</p>
</div>


```r
table(Cluster=colLabels(merged.muraro), Donor=merged.muraro$batch)
```

```
##        Donor
## Cluster D28 D29 D30 D31
##      1  104   6  57 112
##      2   59  21  77  97
##      3   12  75  64  43
##      4   28 149 126 120
##      5   87 261 277 214
##      6   21   7  54  26
##      7    1   6   6  37
##      8    6   6   5   2
##      9   11  68   5  30
##      10   4   2   5   8
```


```r
gridExtra::grid.arrange(
    plotTSNE(merged.muraro, colour_by="label"),
    plotTSNE(merged.muraro, colour_by="batch"),
    ncol=2
)
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-tsne-1.png" alt="Obligatory $t$-SNE plots of the Muraro pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right)." width="672" />
<p class="caption">(\#fig:unref-muraro-tsne)Obligatory $t$-SNE plots of the Muraro pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right).</p>
</div>

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.4.0 RC (2024-04-16 r86468)
Platform: x86_64-pc-linux-gnu
Running under: Ubuntu 22.04.4 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.20-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.10.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] pheatmap_1.0.12             batchelor_1.19.1           
 [3] scran_1.31.3                scater_1.31.2              
 [5] ggplot2_3.5.1               scuttle_1.13.1             
 [7] ensembldb_2.27.1            AnnotationFilter_1.27.0    
 [9] GenomicFeatures_1.55.4      AnnotationDbi_1.65.2       
[11] AnnotationHub_3.11.5        BiocFileCache_2.11.2       
[13] dbplyr_2.5.0                scRNAseq_2.17.10           
[15] SingleCellExperiment_1.25.1 SummarizedExperiment_1.33.3
[17] Biobase_2.63.1              GenomicRanges_1.55.4       
[19] GenomeInfoDb_1.39.14        IRanges_2.37.1             
[21] S4Vectors_0.41.7            BiocGenerics_0.49.1        
[23] MatrixGenerics_1.15.1       matrixStats_1.3.0          
[25] BiocStyle_2.31.0            rebook_1.13.0              

loaded via a namespace (and not attached):
  [1] BiocIO_1.13.1             bitops_1.0-7             
  [3] filelock_1.0.3            tibble_3.2.1             
  [5] CodeDepends_0.6.6         graph_1.81.1             
  [7] XML_3.99-0.16.1           lifecycle_1.0.4          
  [9] httr2_1.0.1               edgeR_4.1.33             
 [11] lattice_0.22-6            alabaster.base_1.3.23    
 [13] magrittr_2.0.3            limma_3.59.10            
 [15] sass_0.4.9                rmarkdown_2.26           
 [17] jquerylib_0.1.4           yaml_2.3.8               
 [19] metapod_1.11.1            cowplot_1.1.3            
 [21] DBI_1.2.2                 RColorBrewer_1.1-3       
 [23] ResidualMatrix_1.13.0     abind_1.4-5              
 [25] zlibbioc_1.49.3           Rtsne_0.17               
 [27] purrr_1.0.2               RCurl_1.98-1.14          
 [29] rappdirs_0.3.3            GenomeInfoDbData_1.2.12  
 [31] ggrepel_0.9.5             irlba_2.3.5.1            
 [33] alabaster.sce_1.3.3       dqrng_0.3.2              
 [35] DelayedMatrixStats_1.25.4 codetools_0.2-20         
 [37] DelayedArray_0.29.9       tidyselect_1.2.1         
 [39] UCSC.utils_0.99.7         farver_2.1.1             
 [41] ScaledMatrix_1.11.1       viridis_0.6.5            
 [43] GenomicAlignments_1.39.5  jsonlite_1.8.8           
 [45] BiocNeighbors_1.21.2      tools_4.4.0              
 [47] Rcpp_1.0.12               glue_1.7.0               
 [49] gridExtra_2.3             SparseArray_1.3.7        
 [51] xfun_0.43                 dplyr_1.1.4              
 [53] HDF5Array_1.31.6          gypsum_0.99.19           
 [55] withr_3.0.0               BiocManager_1.30.22      
 [57] fastmap_1.1.1             rhdf5filters_1.15.5      
 [59] bluster_1.13.0            fansi_1.0.6              
 [61] digest_0.6.35             rsvd_1.0.5               
 [63] R6_2.5.1                  mime_0.12                
 [65] colorspace_2.1-0          RSQLite_2.3.6            
 [67] paws.storage_0.5.0        utf8_1.2.4               
 [69] generics_0.1.3            rtracklayer_1.63.3       
 [71] httr_1.4.7                S4Arrays_1.3.7           
 [73] pkgconfig_2.0.3           gtable_0.3.5             
 [75] blob_1.2.4                XVector_0.43.1           
 [77] htmltools_0.5.8.1         bookdown_0.39            
 [79] ProtGenerics_1.35.4       scales_1.3.0             
 [81] alabaster.matrix_1.3.13   png_0.1-8                
 [83] knitr_1.46                rjson_0.2.21             
 [85] curl_5.2.1                cachem_1.0.8             
 [87] rhdf5_2.47.7              BiocVersion_3.19.1       
 [89] parallel_4.4.0            vipor_0.4.7              
 [91] restfulr_0.0.15           pillar_1.9.0             
 [93] grid_4.4.0                alabaster.schemas_1.3.1  
 [95] vctrs_0.6.5               BiocSingular_1.19.0      
 [97] beachmat_2.19.4           cluster_2.1.6            
 [99] beeswarm_0.4.0            evaluate_0.23            
[101] cli_3.6.2                 locfit_1.5-9.9           
[103] compiler_4.4.0            Rsamtools_2.19.4         
[105] rlang_1.1.3               crayon_1.5.2             
[107] paws.common_0.7.2         labeling_0.4.3           
[109] ggbeeswarm_0.7.2          alabaster.se_1.3.4       
[111] viridisLite_0.4.2         BiocParallel_1.37.1      
[113] munsell_0.5.1             Biostrings_2.71.6        
[115] lazyeval_0.2.2            Matrix_1.7-0             
[117] dir.expiry_1.11.0         ExperimentHub_2.11.3     
[119] sparseMatrixStats_1.15.1  bit64_4.0.5              
[121] Rhdf5lib_1.25.3           KEGGREST_1.43.1          
[123] statmod_1.5.0             alabaster.ranges_1.3.3   
[125] highr_0.10                igraph_2.0.3             
[127] memoise_2.0.1             bslib_0.7.0              
[129] bit_4.0.5                
```
</div>
